@@ -119,7 +119,7 @@ Options::Options()
     , M_focus_type( FOCUS_POINT )
     , M_focus_point( 0.0, 0.0 )
     , M_selected_number( 0 )
-    , M_player_select_type( SELECT_UNSELECT )
+    , M_agent_select_type( SELECT_UNSELECT )
       // view options
     , M_anonymous_mode( false )
     , M_field_grass_type( GRASS_NORMAL )
@@ -1011,9 +1011,9 @@ Options::updateFocusPoint( const double & x,
 
  */
 void
-Options::unselectPlayer()
+Options::unselectAgent()
 {
-    M_player_select_type = Options::SELECT_UNSELECT;
+    M_agent_select_type = Options::SELECT_UNSELECT;
     setSelectedNumber( rcsc::NEUTRAL, 0 );
     M_focus_type = Options::FOCUS_POINT;
 }
@@ -1023,15 +1023,15 @@ Options::unselectPlayer()
 
  */
 void
-Options::setPlayerSelectType( const Options::PlayerSelectType type )
+Options::setAgentSelectType( const Options::AgentSelectType type )
 {
     if ( type != Options::SELECT_FIX
-         && type == M_player_select_type )
+         && type == M_agent_select_type )
     {
-        unselectPlayer();
+        unselectAgent();
     }
     else
     {
-        M_player_select_type = type;
+        M_agent_select_type = type;
     }
 }
