@@ -58,12 +58,14 @@ public:
         PAINT_RCSSMONITOR,
     };
 
-    enum PlayerSelectType {
-        SELECT_FIX,
-        SELECT_AUTO_LEFT,
-        SELECT_AUTO_RIGHT,
-        SELECT_AUTO_ALL,
-        SELECT_UNSELECT,
+    enum AgentSelectType {
+        SELECT_FIX = 0 ,
+        SELECT_AUTO_LEFT = 1,
+        SELECT_AUTO_RIGHT = -1,
+        SELECT_AUTO_ALL = 2,
+        SELECT_COACH_LEFT = 3,
+        SELECT_COACH_RIGHT = -3,
+        SELECT_UNSELECT = 4,
     };
 
     enum FocusType {
@@ -146,7 +148,7 @@ private:
     rcsc::Vector2D M_focus_point; //!< real coordinates
 
     int M_selected_number; //!< selected player's uniform number(if right side team, negative value is set)
-    PlayerSelectType M_player_select_type; //!< flag for player auto selection
+    AgentSelectType M_agent_select_type; //!< player/coach selection type
 
     //
     // view options
@@ -357,13 +359,13 @@ public:
                            const double & y );
     const rcsc::Vector2D & focusPoint() const { return M_focus_point; }
 
-    void unselectPlayer();
-    void setPlayerSelectType( const PlayerSelectType type );
-    PlayerSelectType playerSelectType() const { return M_player_select_type; }
-    bool playerAutoSelect() const
+    void unselectAgent();
+    void setAgentSelectType( const AgentSelectType type );
+    AgentSelectType agentSelectType() const { return M_agent_select_type; }
+    bool isPlayerAutoSelect() const
       {
-          return ( M_player_select_type != SELECT_FIX
-                   && M_player_select_type != SELECT_UNSELECT );
+          return ( M_agent_select_type == SELECT_AUTO_LEFT
+                   || M_agent_select_type == SELECT_AUTO_RIGHT );
       }
     void setSelectedNumber( rcsc::SideID side,
                             int unum )
@@ -371,8 +373,8 @@ public:
           M_selected_number = ( side == rcsc::LEFT ? unum : -unum );
       }
     int selectedNumber() const { return M_selected_number; }
-    bool isSelectedPlayer( rcsc::SideID side,
-                           int unum ) const
+    bool isSelectedAgent( rcsc::SideID side,
+                          int unum ) const
       {
           return ( M_selected_number == ( side == rcsc::LEFT ? unum : -unum ) );
       }
