@@ -623,6 +623,14 @@ DebugMessageWindow::createWindows()
         M_tab_widget->addTab( M_message[i],
                               QString( "   %1 " ).arg( i + 1, 2 ) );
     }
+
+    {
+        M_message[11] = new QTextEdit();
+        M_message[11]->setReadOnly( true );
+        M_message[11]->setWordWrapMode( QTextOption::NoWrap );
+        M_tab_widget->addTab( M_message[11], tr( "Coach" ) );
+    }
+
     M_tab_widget->selectIndex( 0 );
 }
 
@@ -1003,6 +1011,8 @@ DebugMessageWindow::decrementCycle()
     }
 
     updateMessage();
+
+    emit selectCycle( M_main_data.getDebugLogHolder().getCurrentCycle() );
 }
 
 /*-------------------------------------------------------------------*/
@@ -1019,6 +1029,8 @@ DebugMessageWindow::incrementCycle()
     }
 
     updateMessage();
+
+    emit selectCycle( M_main_data.getDebugLogHolder().getCurrentCycle() );
 }
 
 /*-------------------------------------------------------------------*/
@@ -1095,9 +1107,9 @@ DebugMessageWindow::clearAll()
 {
     M_main_data.getDebugLogHolder().clear();
 
-    for ( int i = 0; i < 11; ++i )
+    for ( int i = 0; i < 12; ++i )
     {
-        M_message[i ]->clear();
+        M_message[i]->clear();
     }
 }
 
