@@ -66,11 +66,15 @@ private:
 
     void drawPlayers( QPainter &painter,
                       const rcsc::SideID self_side,
-                      const DebugViewData & view,
+                      // const DebugViewData & view,
                       const DebugViewData::PlayerCont & players,
-                      const int target_number,
+                      // const int target_number,
                       const QBrush & body_brush ) const;
 
+    void drawTarget( QPainter & painter,
+                     const rcsc::SideID self_side,
+                     const DebugViewData & view ) const;
+
     void drawLines( QPainter & painter,
                     const rcsc::SideID self_side,
                     const DebugViewData & view ) const;
