@@ -75,6 +75,10 @@ private:
     QLabel * M_player_body;
     QLabel * M_player_head;
 
+    //QLabel * M_player_catch_prob;
+    QLabel * M_player_tackle_prob;
+    QLabel * M_player_foul_prob;
+
     QLabel * M_player_pointto_pos;
 
     QLabel * M_player_focus_target;
