@@ -66,10 +66,11 @@ const QColor DrawConfig::KICK_PEN_COLOR = QColor( 255, 255, 255 );
 const QColor DrawConfig::KICK_FAULT_COLOR = QColor( 0, 255, 0 );
 const QColor DrawConfig::CATCH_COLOR = QColor( 10, 80, 10 );
 const QColor DrawConfig::CATCH_FAULT_COLOR = QColor( 10, 80, 150 );
-const QColor DrawConfig::COLLIDE_BALL_COLOR = QColor( 5, 255, 255 );
-const QColor DrawConfig::COLLIDE_PLAYER_COLOR = QColor( 105, 185, 255 );
+const QColor DrawConfig::BALL_COLLISION_COLOR = QColor( 5, 255, 255 );
+const QColor DrawConfig::PLAYER_COLLISION_COLOR = QColor( 105, 185, 255 );
 const QColor DrawConfig::TACKLE_COLOR = QColor( 255, 136, 127 );
 const QColor DrawConfig::TACKLE_FAULT_COLOR = QColor( 79, 159, 159 );
+const QColor DrawConfig::FOUL_CHARGED_COLOR = QColor( 0, 127, 0 );
 const QColor DrawConfig::POINTTO_COLOR = QColor( 255, 136, 127 );
 //const QColor DrawConfig::ATTENTIONTO_COLOR = QColor( 0, 255, 0 );
 const QColor DrawConfig::MEASURE_COLOR = QColor( 0, 255, 255 );
@@ -110,10 +111,12 @@ DrawConfig::DrawConfig()
     , M_left_team_pen( LEFT_TEAM_COLOR, 0, Qt::SolidLine )
     , M_left_team_brush( LEFT_TEAM_COLOR, Qt::SolidPattern )
     , M_left_goalie_pen( LEFT_GOALIE_COLOR, 0, Qt::SolidLine )
+    , M_left_goalie_stretch_pen( LEFT_GOALIE_COLOR, 0, Qt::DotLine )
     , M_left_goalie_brush( LEFT_GOALIE_COLOR, Qt::SolidPattern )
     , M_right_team_pen( RIGHT_TEAM_COLOR, 0, Qt::SolidLine )
     , M_right_team_brush( RIGHT_TEAM_COLOR, Qt::SolidPattern )
     , M_right_goalie_pen( RIGHT_GOALIE_COLOR, 0, Qt::SolidLine )
+    , M_right_goalie_stretch_pen( RIGHT_GOALIE_COLOR, 0, Qt::DotLine )
     , M_right_goalie_brush( RIGHT_GOALIE_COLOR, Qt::SolidPattern )
     , M_player_font( "Sans Serif", 10 )
     , M_player_number_font_pen( PLAYER_NUMBER_FONT_COLOR, 0, Qt::SolidLine )
@@ -129,11 +132,12 @@ DrawConfig::DrawConfig()
     , M_kick_fault_brush( KICK_FAULT_COLOR, Qt::SolidPattern )
     , M_catch_brush( CATCH_COLOR, Qt::SolidPattern )
     , M_catch_fault_brush( CATCH_FAULT_COLOR, Qt::SolidPattern )
-    , M_collide_ball_brush( COLLIDE_BALL_COLOR, Qt::SolidPattern )
-    , M_collide_player_brush( COLLIDE_PLAYER_COLOR, Qt::SolidPattern )
+    , M_ball_collision_brush( BALL_COLLISION_COLOR, Qt::SolidPattern )
+    , M_player_collision_brush( PLAYER_COLLISION_COLOR, Qt::SolidPattern )
     , M_tackle_pen( TACKLE_COLOR, 2, Qt::SolidLine )
     , M_tackle_brush( TACKLE_COLOR, Qt::SolidPattern )
     , M_tackle_fault_brush( TACKLE_FAULT_COLOR, Qt::SolidPattern )
+    , M_foul_charged_brush( FOUL_CHARGED_COLOR, Qt::SolidPattern )
     , M_pointto_pen( POINTTO_COLOR, 0, Qt::SolidLine )
       //    , M_attentionto_pen( ATTENTIONTO_COLOR, 0, Qt::SolidLine )
     , M_kick_accel_pen( QColor( 0, 255, 0 ), 0, Qt::SolidLine )
@@ -141,7 +145,6 @@ DrawConfig::DrawConfig()
     , M_measure_pen( MEASURE_COLOR, 1, Qt::SolidLine )
     , M_measure_font( "Sans Serif", 10 )
     , M_measure_font_pen( MEASURE_FONT_COLOR, 0, Qt::SolidLine )
-    , M_debug_ball_pen( QColor( 127, 127, 127 ), 0, Qt::SolidLine )
     , M_debug_ball_brush( DEBUG_BALL_COLOR, Qt::SolidPattern )
     , M_debug_ball_trace_pen( DEBUG_BALL_COLOR, 0, Qt::SolidLine )
     , M_debug_ball_trace_brush( DEBUG_BALL_COLOR, Qt::SolidPattern )
@@ -202,10 +205,12 @@ DrawConfig::setDefaultColors()
     M_left_team_pen.setColor( LEFT_TEAM_COLOR );
     M_left_team_brush.setColor( LEFT_TEAM_COLOR );
     M_left_goalie_pen.setColor( LEFT_GOALIE_COLOR );
+    M_left_goalie_stretch_pen.setColor( LEFT_GOALIE_COLOR );
     M_left_goalie_brush.setColor( LEFT_GOALIE_COLOR );
     M_right_team_pen.setColor( RIGHT_TEAM_COLOR );
     M_right_team_brush.setColor( RIGHT_TEAM_COLOR );
     M_right_goalie_pen.setColor( RIGHT_GOALIE_COLOR );
+    M_right_goalie_stretch_pen.setColor( RIGHT_GOALIE_COLOR );
     M_right_goalie_brush.setColor( RIGHT_GOALIE_COLOR );
     M_player_number_font_pen.setColor( PLAYER_NUMBER_FONT_COLOR );
     M_player_stamina_font_pen.setColor( PLAYER_STAMINA_FONT_COLOR );
@@ -220,18 +225,18 @@ DrawConfig::setDefaultColors()
     M_kick_fault_brush.setColor( KICK_FAULT_COLOR );
     M_catch_brush.setColor( CATCH_COLOR );
     M_catch_fault_brush.setColor( CATCH_FAULT_COLOR );
-    M_collide_ball_brush.setColor( COLLIDE_BALL_COLOR );
-    M_collide_player_brush.setColor( COLLIDE_PLAYER_COLOR );
+    M_ball_collision_brush.setColor( BALL_COLLISION_COLOR );
+    M_player_collision_brush.setColor( PLAYER_COLLISION_COLOR );
     M_tackle_pen.setColor( TACKLE_COLOR );
     M_tackle_brush.setColor( TACKLE_COLOR );
     M_tackle_fault_brush.setColor( TACKLE_FAULT_COLOR );
+    M_foul_charged_brush.setColor( FOUL_CHARGED_COLOR );
     M_pointto_pen.setColor( POINTTO_COLOR );
     //    M_attentionto_pen.setColor( ATTENTIONTO_COLOR );
     M_kick_accel_pen.setColor( QColor( 0, 255, 0 ) );
     M_tackle_area_pen.setColor( TACKLE_COLOR );
     M_measure_pen.setColor( MEASURE_COLOR );
     M_measure_font_pen.setColor( MEASURE_FONT_COLOR );
-    M_debug_ball_pen.setColor( QColor( 127, 127, 127 ) );
     M_debug_ball_brush.setColor( DEBUG_BALL_COLOR );
     M_debug_ball_trace_pen.setColor( DEBUG_BALL_COLOR );
     M_debug_ball_trace_brush.setColor( DEBUG_BALL_COLOR );
@@ -416,6 +421,7 @@ DrawConfig::readSettings()
     if ( val.isValid() )
     {
         M_left_goalie_pen.setColor( toColor( val.toString() ) );
+        M_left_goalie_stretch_pen.setColor( toColor( val.toString() ) );
         M_left_goalie_brush.setColor( toColor( val.toString() ) );
     }
 
@@ -430,6 +436,7 @@ DrawConfig::readSettings()
     if ( val.isValid() )
     {
         M_right_goalie_pen.setColor( toColor( val.toString() ) );
+        M_right_goalie_stretch_pen.setColor( toColor( val.toString() ) );
         M_right_goalie_brush.setColor( toColor( val.toString() ) );
     }
 
@@ -508,16 +515,16 @@ DrawConfig::readSettings()
         M_catch_fault_brush.setColor( toColor( val.toString() ) );
     }
 
-    val = settings.value( "collide_ball_color" );
+    val = settings.value( "ball_collision_color" );
     if ( val.isValid() )
     {
-        M_collide_ball_brush.setColor( toColor( val.toString() ) );
+        M_ball_collision_brush.setColor( toColor( val.toString() ) );
     }
 
-    val = settings.value( "collide_player_color" );
+    val = settings.value( "player_collision_color" );
     if ( val.isValid() )
     {
-        M_collide_player_brush.setColor( toColor( val.toString() ) );
+        M_player_collision_brush.setColor( toColor( val.toString() ) );
     }
 
     val = settings.value( "tackle_color" );
@@ -539,6 +546,12 @@ DrawConfig::readSettings()
         M_tackle_fault_brush.setColor( toColor( val.toString() ) );
     }
 
+    val = settings.value( "foul_charged_color" );
+    if ( val.isValid() )
+    {
+        M_foul_charged_brush.setColor( toColor( val.toString() ) );
+    }
+
     val = settings.value( "pointto_color" );
     if ( val.isValid() )
     {
@@ -734,16 +747,18 @@ DrawConfig::saveSettings()
                        toString( catchBrush().color() ) );
     settings.setValue( "catch_fault_color",
                        toString( catchFaultBrush().color() ) );
-    settings.setValue( "collide_ball_color",
-                       toString( collideBallBrush().color() ) );
-    settings.setValue( "collide_player_color",
-                       toString( collidePlayerBrush().color() ) );
+    settings.setValue( "ball_collision_color",
+                       toString( ballCollisionBrush().color() ) );
+    settings.setValue( "player_collision_color",
+                       toString( playerCollisionBrush().color() ) );
     settings.setValue( "tackle_color",
                        toString( tackleBrush().color() ) );
     settings.setValue( "tackle_area_color",
                        toString( tackleAreaPen().color() ) );
     settings.setValue( "tackle_fault_color",
                        toString( tackleFaultBrush().color() ) );
+    settings.setValue( "foul_charged_color",
+                       toString( foulChargedBrush().color() ) );
     settings.setValue( "pointto_color",
                        toString( pointtoPen().color() ) );
 //     settings.setValue( "attentionto_color",
