@@ -36,12 +36,11 @@
 
 class QAction;
 class QBoxLayout;
-class QMainWindow;
 class QSlider;
 class QLineEdit;
 class QMoveEvent;
+class QWidget;
 
-class LogPlayer;
 class MainData;
 
 class LogPlayerToolBar
@@ -52,23 +51,18 @@ class LogPlayerToolBar
 private:
 
     const MainData & M_main_data;
-    LogPlayer * M_log_player;
 
     QSlider * M_cycle_slider;
     QLineEdit * M_cycle_edit;
-    //QBoxLayout * M_stretch_layout;
 
 public:
 
-    LogPlayerToolBar( LogPlayer * log_player,
-                      const MainData & main_data,
-                      QMainWindow * main_win );
+    LogPlayerToolBar( const MainData & main_data,
+                      QWidget * parent );
     ~LogPlayerToolBar();
 
-private:
-
-    void createControls( LogPlayer * log_player,
-                         QMainWindow * main_win );
+    void createCycleSlider();
+    void createCycleEdit();
 
 protected:
 
@@ -78,10 +72,6 @@ private slots:
 
     void editCycle();
 
-    void stop();
-    void playForward();
-    void playBack();
-
 public slots:
 
     void changeOrientation( Qt::Orientation );
@@ -90,6 +80,7 @@ public slots:
 
 signals:
 
+    void indexChanged( int idx );
     void cycleChanged( int cycle );
 
 };
