@@ -671,6 +671,7 @@ MonitorMoveDialog::open()
     M_ball_x->setEnabled( false );
     M_ball_y->setEnabled( false );
     M_drop_ball_rb->setChecked( true );
+
     for ( int i = 0; i < 11; ++i )
     {
         M_left_cb[i]->setChecked( false );
@@ -690,7 +691,7 @@ MonitorMoveDialog::open()
     {
         ++n_line;
 
-        char str_id[8];
+        char str_id[32];
         int unum;
         char str_x[32];
         char str_y[32];
@@ -738,10 +739,10 @@ MonitorMoveDialog::open()
                 }
 
                 M_ball_cb->setChecked( true );
-                M_ball_x->setText( QString::fromAscii( str_x ) );
-                M_ball_y->setText( QString::fromAscii( str_y ) );
                 M_ball_x->setEnabled( true );
                 M_ball_y->setEnabled( true );
+                M_ball_x->setText( QString::fromAscii( str_x ) );
+                M_ball_y->setText( QString::fromAscii( str_y ) );
 
                 if ( str_vx[0] != '*'
                      && str_vy[0] != '*' )
@@ -758,14 +759,12 @@ MonitorMoveDialog::open()
                     }
 
                     M_ball_vel_cb->setChecked( true );
-                    M_ball_vx->setText( QString::fromAscii( str_vx ) );
-                    M_ball_vy->setText( QString::fromAscii( str_vy ) );
                     M_ball_vx->setEnabled( true );
                     M_ball_vy->setEnabled( true );
+                    M_ball_vx->setText( QString::fromAscii( str_vx ) );
+                    M_ball_vy->setText( QString::fromAscii( str_vy ) );
                 }
             }
-
-            continue;
         }
         else if ( std::sscanf( line_buf.c_str(),
                                " %31s %d %31s %31s %31s ",
@@ -783,7 +782,7 @@ MonitorMoveDialog::open()
             }
             else
             {
-                std::cerr << "Illega data at line " << n_line
+                std::cerr << "Illegal data at line " << n_line
                           << " : [" << line_buf << "]"
                           << std::endl;
                 continue;
@@ -791,14 +790,15 @@ MonitorMoveDialog::open()
 
             if ( unum < 1 || 11 < unum )
             {
-                std::cerr << "Illega data at line " << n_line
+                std::cerr << "Illegal data at line " << n_line
                           << " : [" << line_buf << "]"
                           << std::endl;
                 continue;
             }
 
             if ( str_x[0] == '*'
-                 || str_y[0] == '*' )
+                 || str_y[0] == '*'
+                 || str_body[0] == '*' )
             {
                 continue;
             }
@@ -819,23 +819,23 @@ MonitorMoveDialog::open()
 
             if ( side == rcsc::LEFT )
             {
-                M_left_x[unum-1]->setText( QString::fromAscii( str_x ) );
-                M_left_y[unum-1]->setText( QString::fromAscii( str_y ) );
-                M_left_body[unum-1]->setText( QString::fromAscii( str_body ) );
                 M_left_cb[unum-1]->setChecked( true );
                 M_left_x[unum-1]->setEnabled( true );
                 M_left_y[unum-1]->setEnabled( true );
                 M_left_body[unum-1]->setEnabled( true );
+                M_left_x[unum-1]->setText( QString::fromAscii( str_x ) );
+                M_left_y[unum-1]->setText( QString::fromAscii( str_y ) );
+                M_left_body[unum-1]->setText( QString::fromAscii( str_body ) );
             }
             if ( side == rcsc::RIGHT )
             {
-                M_right_x[unum-1]->setText( QString::fromAscii( str_x ) );
-                M_right_y[unum-1]->setText( QString::fromAscii( str_y ) );
-                M_right_body[unum-1]->setText( QString::fromAscii( str_body ) );
                 M_right_cb[unum-1]->setChecked( true );
                 M_right_x[unum-1]->setEnabled( true );
                 M_right_y[unum-1]->setEnabled( true );
                 M_right_body[unum-1]->setEnabled( true );
+                M_right_x[unum-1]->setText( QString::fromAscii( str_x ) );
+                M_right_y[unum-1]->setText( QString::fromAscii( str_y ) );
+                M_right_body[unum-1]->setText( QString::fromAscii( str_body ) );
             }
         }
         else
@@ -998,7 +998,7 @@ MonitorMoveDialog::sendCommand()
             if ( reverse )
             {
                 pos *= -1.0;
-                if ( vel.valid() ) vel *= -1.0;
+                if ( vel.isValid() ) vel *= -1.0;
             }
             M_trainer_data.setBall( pos, vel );
         }
