@@ -174,7 +174,7 @@ PlayerPainterRCSS::draw( QPainter & painter )
                 break;
             }
 
-            if ( opt.isSelectedPlayer( it->side(), it->unum() ) )
+            if ( opt.isSelectedAgent( it->side(), it->unum() ) )
             {
                 drawViewAreaBackground( painter, *it );
                 break;
@@ -223,7 +223,7 @@ PlayerPainterRCSS::drawAll(  QPainter & painter,
     //drawShadow( painter, param );
     drawEdge( painter, param );
 
-    if ( opt.isSelectedPlayer( player.side(), player.unum() )
+    if ( opt.isSelectedAgent( player.side(), player.unum() )
          && opt.playerFutureCycle() > 0
          && player.hasDelta() )
     {
