@@ -704,22 +704,28 @@ ViewConfigDialog::createPlayerSelectionControls()
         layout->setSpacing( 0 );
         //layout->addSpacing( 16 );
 
-        M_player_choice = new QComboBox();
-        M_player_choice->addItem( tr ( "No Selection" ) );
+        M_agent_choice = new QComboBox();
+        M_agent_choice->addItem( tr ( "No Selection" ) );
+
         for ( int i = 1; i <= 11; ++i )
         {
-            M_player_choice->addItem( QString( "Left number: %1" ).arg( i ) );
+            M_agent_choice->addItem( QString( "Left number: %1" ).arg( i ) );
         }
+        M_agent_choice->addItem( tr( "Left Coach" ) );
+
         for ( int i = 1; i <= 11; ++i )
         {
-            M_player_choice->addItem( QString( "Right number: %1" ).arg( i ) );
+            M_agent_choice->addItem( QString( "Right number: %1" ).arg( i ) );
         }
-        M_player_choice->setCurrentIndex( 0 );
+        M_agent_choice->addItem( tr( "Right Coach" ) );
+
+        M_agent_choice->setCurrentIndex( 0 );
+
         int id_width = this->fontMetrics().width( tr( "Right Number: 11" ) );
-        M_player_choice->setMaximumWidth( id_width + 40 );
-        connect( M_player_choice, SIGNAL( currentIndexChanged( int ) ),
-                 this, SLOT( choicePlayer( int ) ) );
-        layout->addWidget( M_player_choice, 0, Qt::AlignLeft );
+        M_agent_choice->setMaximumWidth( id_width + 40 );
+        connect( M_agent_choice, SIGNAL( currentIndexChanged( int ) ),
+                 this, SLOT( choiceAgent( int ) ) );
+        layout->addWidget( M_agent_choice, 0, Qt::AlignLeft );
 
         layout->addSpacing( 16 );
 
@@ -1262,7 +1268,7 @@ ViewConfigDialog::updateAll()
         break;
     }
 
-    switch ( opt.playerSelectType() ) {
+    switch ( opt.agentSelectType() ) {
     case Options::SELECT_AUTO_ALL:
         M_select_all_rb->setChecked( true );
         break;
@@ -2419,9 +2425,9 @@ ViewConfigDialog::setFocusPoint( const QPoint & point )
 void
 ViewConfigDialog::clickSelectAutoAll()
 {
-    if ( Options::instance().playerSelectType() != Options::SELECT_AUTO_ALL )
+    if ( Options::instance().agentSelectType() != Options::SELECT_AUTO_ALL )
     {
-        Options::instance().setPlayerSelectType( Options::SELECT_AUTO_ALL );
+        Options::instance().setAgentSelectType( Options::SELECT_AUTO_ALL );
         emit configured();
     }
 }
@@ -2433,13 +2439,13 @@ ViewConfigDialog::clickSelectAutoAll()
 void
 ViewConfigDialog::toggleSelectAutoAll()
 {
-    if ( Options::instance().playerSelectType() == Options::SELECT_AUTO_ALL )
+    if ( Options::instance().agentSelectType() == Options::SELECT_AUTO_ALL )
     {
         setUnselect();
     }
     else
     {
-        Options::instance().setPlayerSelectType( Options::SELECT_AUTO_ALL );
+        Options::instance().setAgentSelectType( Options::SELECT_AUTO_ALL );
         M_select_all_rb->setChecked( true );
 
         emit configured();
@@ -2453,13 +2459,13 @@ ViewConfigDialog::toggleSelectAutoAll()
 void
 ViewConfigDialog::clickSelectAutoLeft()
 {
-    Options::PlayerSelectType type = ( Options::instance().reverseSide()
-                                       ? Options::SELECT_AUTO_RIGHT
-                                       : Options::SELECT_AUTO_LEFT );
+    Options::AgentSelectType type = ( Options::instance().reverseSide()
+                                      ? Options::SELECT_AUTO_RIGHT
+                                      : Options::SELECT_AUTO_LEFT );
 
-    if ( Options::instance().playerSelectType() != type )
+    if ( Options::instance().agentSelectType() != type )
     {
-        Options::instance().setPlayerSelectType( type );
+        Options::instance().setAgentSelectType( type );
         emit configured();
     }
 }
@@ -2471,17 +2477,17 @@ ViewConfigDialog::clickSelectAutoLeft()
 void
 ViewConfigDialog::toggleSelectAutoLeft()
 {
-    Options::PlayerSelectType type = ( Options::instance().reverseSide()
-                                       ? Options::SELECT_AUTO_RIGHT
-                                       : Options::SELECT_AUTO_LEFT );
+    Options::AgentSelectType type = ( Options::instance().reverseSide()
+                                      ? Options::SELECT_AUTO_RIGHT
+                                      : Options::SELECT_AUTO_LEFT );
 
-    if ( Options::instance().playerSelectType() == type )
+    if ( Options::instance().agentSelectType() == type )
     {
         setUnselect();
     }
     else
     {
-        Options::instance().setPlayerSelectType( type );
+        Options::instance().setAgentSelectType( type );
         M_select_left_rb->setChecked( true );
 
         emit configured();
@@ -2495,13 +2501,13 @@ ViewConfigDialog::toggleSelectAutoLeft()
 void
 ViewConfigDialog::clickSelectAutoRight()
 {
-    Options::PlayerSelectType type = ( Options::instance().reverseSide()
-                                       ? Options::SELECT_AUTO_LEFT
-                                       : Options::SELECT_AUTO_RIGHT );
+    Options::AgentSelectType type = ( Options::instance().reverseSide()
+                                      ? Options::SELECT_AUTO_LEFT
+                                      : Options::SELECT_AUTO_RIGHT );
 
-    if ( Options::instance().playerSelectType() != type )
+    if ( Options::instance().agentSelectType() != type )
     {
-        Options::instance().setPlayerSelectType( type );
+        Options::instance().setAgentSelectType( type );
         emit configured();
     }
 }
@@ -2513,17 +2519,17 @@ ViewConfigDialog::clickSelectAutoRight()
 void
 ViewConfigDialog::toggleSelectAutoRight()
 {
-    Options::PlayerSelectType type = ( Options::instance().reverseSide()
-                                       ? Options::SELECT_AUTO_LEFT
-                                       : Options::SELECT_AUTO_RIGHT );
+    Options::AgentSelectType type = ( Options::instance().reverseSide()
+                                      ? Options::SELECT_AUTO_LEFT
+                                      : Options::SELECT_AUTO_RIGHT );
 
-    if ( Options::instance().playerSelectType() == type )
+    if ( Options::instance().agentSelectType() == type )
     {
         setUnselect();
     }
     else
     {
-        Options::instance().setPlayerSelectType( type );
+        Options::instance().setAgentSelectType( type );
         M_select_right_rb->setChecked( true );
 
         emit configured();
@@ -2537,9 +2543,9 @@ ViewConfigDialog::toggleSelectAutoRight()
 void
 ViewConfigDialog::clickSelectFix()
 {
-    if ( Options::instance().playerSelectType() != Options::SELECT_FIX )
+    if ( Options::instance().agentSelectType() != Options::SELECT_FIX )
     {
-        Options::instance().setPlayerSelectType( Options::SELECT_AUTO_RIGHT );
+        Options::instance().setAgentSelectType( Options::SELECT_AUTO_RIGHT );
         emit configured();
     }
 }
@@ -2551,13 +2557,13 @@ ViewConfigDialog::clickSelectFix()
 void
 ViewConfigDialog::toggleSelectFix()
 {
-    if ( Options::instance().playerSelectType() == Options::SELECT_FIX )
+    if ( Options::instance().agentSelectType() == Options::SELECT_FIX )
     {
         setUnselect();
     }
     else
     {
-        Options::instance().setPlayerSelectType( Options::SELECT_FIX );
+        Options::instance().setAgentSelectType( Options::SELECT_FIX );
         M_select_fix_rb->setChecked( true );
 
         emit configured();
@@ -2571,9 +2577,9 @@ ViewConfigDialog::toggleSelectFix()
 void
 ViewConfigDialog::setUnselect()
 {
-    Options::instance().unselectPlayer();
+    Options::instance().unselectAgent();
     M_unselect_rb->setChecked( true );
-    M_player_choice->setCurrentIndex( 0 );
+    M_agent_choice->setCurrentIndex( 0 );
 
     emit configured();
 }
@@ -2583,13 +2589,13 @@ ViewConfigDialog::setUnselect()
 
  */
 void
-ViewConfigDialog::selectPlayer( int number )
+ViewConfigDialog::selectAgent( int number )
 {
-    // left side:  number = [1,11]
-    // right side:  number = [12,22]
+    // left side:  number = [1,12]
+    // right side:  number = [13,24]
 
-    if ( number <= 0
-         || 22 < number )
+    if ( number < 1
+         || 24 < number )
     {
         setUnselect();
         return;
@@ -2599,27 +2605,27 @@ ViewConfigDialog::selectPlayer( int number )
 
     if ( Options::instance().reverseSide() )
     {
-        if ( number <= 11 )
+        if ( number <= 12 )
         {
-            number += 11;
+            number += 12;
         }
         else
         {
-            number -= 11;
+            number -= 12;
         }
     }
 
-    Options::instance().setPlayerSelectType( Options::SELECT_FIX );
-    if ( number <= 11 )
+    Options::instance().setAgentSelectType( Options::SELECT_FIX );
+    if ( number <= 12 )
     {
         Options::instance().setSelectedNumber( rcsc::LEFT, number );
     }
     else
     {
-        Options::instance().setSelectedNumber( rcsc::RIGHT, number - 11 );
+        Options::instance().setSelectedNumber( rcsc::RIGHT, number - 12 );
     }
 
-    M_player_choice->setCurrentIndex( orig_number );
+    M_agent_choice->setCurrentIndex( orig_number );
     M_select_fix_rb->setChecked( true );
 
     emit configured();
@@ -2630,34 +2636,34 @@ ViewConfigDialog::selectPlayer( int number )
 
  */
 void
-ViewConfigDialog::choicePlayer( int number )
+ViewConfigDialog::choiceAgent( int number )
 {
     int orig_number = number;
     if ( Options::instance().reverseSide() )
     {
-        if ( number <= 11 )
+        if ( number <= 12 )
         {
-            number += 11;
+            number += 12;
         }
         else
         {
-            number -= 11;
+            number -= 12;
         }
     }
 
-    if ( number <= 11
-         && Options::instance().isSelectedPlayer( rcsc::LEFT, number ) )
+    if ( number <= 12
+         && Options::instance().isSelectedAgent( rcsc::LEFT, number ) )
     {
         return;
     }
 
-    if ( number > 11
-         && Options::instance().isSelectedPlayer( rcsc::RIGHT, number - 11 ) )
+    if ( number > 12
+         && Options::instance().isSelectedAgent( rcsc::RIGHT, number - 12 ) )
     {
         return;
     }
 
-    selectPlayer( orig_number );
+    selectAgent( orig_number );
 }
 
 /*-------------------------------------------------------------------*/
@@ -2665,7 +2671,7 @@ ViewConfigDialog::choicePlayer( int number )
 
  */
 void
-ViewConfigDialog::selectPlayerWithKey()
+ViewConfigDialog::selectAgentWithKey()
 {
     QAction * action = qobject_cast< QAction * >( sender() );
 
@@ -2680,7 +2686,7 @@ ViewConfigDialog::selectPlayerWithKey()
     {
         if ( key == Qt::Key_0 + i )
         {
-            selectPlayer( i );
+            selectAgent( i );
             return;
         }
         else if (
@@ -2691,14 +2697,14 @@ ViewConfigDialog::selectPlayerWithKey()
 #endif
                  )
         {
-            selectPlayer( i + 11 );
+            selectAgent( i + 12 );
             return;
         }
     }
 
     if ( key == Qt::Key_0 )
     {
-        selectPlayer( 10 );
+        selectAgent( 10 );
         return;
     }
 
@@ -2710,13 +2716,13 @@ ViewConfigDialog::selectPlayerWithKey()
 #endif
         )
     {
-        selectPlayer( 21 );
+        selectAgent( 10 + 12 );
         return;
     }
 
     if ( key == Qt::Key_Minus )
     {
-        selectPlayer( 11 );
+        selectAgent( 11 );
         return;
     }
 
@@ -2728,9 +2734,47 @@ ViewConfigDialog::selectPlayerWithKey()
 #endif
         )
     {
-        selectPlayer( 22 );
+        selectAgent( 11 + 12 );
         return;
     }
+
+    if ( key == Qt::Key_Equal )
+    {
+        selectAgent( 12 );
+        return;
+    }
+
+    if (
+#ifdef Q_WS_MAC
+        key == Qt::META + Qt::Key_Equal
+#else
+        key == Qt::CTRL + Qt::Key_Equal
+#endif
+        )
+    {
+        selectAgent( 12 + 12 );
+        return;
+    }
+}
+
+/*-------------------------------------------------------------------*/
+/*!
+
+ */
+void
+ViewConfigDialog::selectLeftCoach()
+{
+    selectAgent( 12 );
+}
+
+/*-------------------------------------------------------------------*/
+/*!
+
+ */
+void
+ViewConfigDialog::selectRightCoach()
+{
+    selectAgent( 12 + 12 );
 }
 
 /*-------------------------------------------------------------------*/
